SinhalaUnicode class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
autoDetectAndConvert(
String text) → String - Auto-detect font type and convert to Unicode
-
getSupportedFonts(
) → List< String> - Get list of supported font types
-
initialize(
) → void - Initialize the converter
-
isFontSupported(
String fontType) → bool - Check if a specific font mapping is available
-
legacyToUnicode(
String text, String fontType) → String - Convert legacy font text to Unicode